@@ -38,15 +38,20 @@ class Dispatcher(object):
         variables = {name: device for name, device in self.devices}
         previous_time = 0
 
-        while True:
-            current_time = round(time.time() * 1000)
-            process_time = current_time // round(self.interval * 1000)
+        try:
+            while True:
+                interval_time = int(self.interval * 1000)
+                current_time = int(time.time() * 1000)
+                process_time = (current_time // interval_time) * interval_time
 
-            if process_time == previous_time:
-                time.sleep(self.interval * 0.1)
-                continue
+                if process_time == previous_time:
+                    next_time = previous_time + interval_time
+                    time.sleep((next_time - current_time) * 0.001)
+                    continue
 
-            previous_time = process_time
+                previous_time = process_time
 
-            for handler in self.handlers:
-                handler(**variables)
+                for handler in self.handlers:
+                    handler(**variables)
+        except StopIteration:
+            print('Stopped by handler')
